@@ -81,7 +81,9 @@ class BootstrapDateInput(forms.DateInput):
         js = (
             settings.STATIC_URL + 'datepicker/js/bootstrap-datepicker.js',
         )
-        lang = translation.get_language().split('-')[0].lower()
+        lang = translation.get_language()
+        if '-' in lang:
+            lang = "%s-%s" % (lang.split('-')[0].lower(), lang.split('-')[1].upper())
         if lang != 'en':
             js = js + (
                 settings.STATIC_URL + 'datepicker/js/locales/bootstrap-datepicker.%s.js' % lang,
